<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>CustomDialog</name>
    <message>
        <location filename="../dialog.cpp" line="16"/>
        <source>Live environment detected. Please select the root partition of the
 system you want to modify (only Linux partitions are displayed)</source>
        <translation>Live-tila havaittu. Valitse juuri-osio 
jota haluat järjestelmässä muokata (vain Linux-osiot ovat näkyvillä)</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="22"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="23"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>Options</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="39"/>
        <source>Use simplified menu structure without submenus</source>
        <translation>Käytä yksinkertaistettua valikkorakennetta ilman jatkevalikkoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="42"/>
        <source>Use flat menus (no submenus)</source>
        <translation>Käytä yleisvalikkoja (ei jatkevalikkoja)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Boot to</source>
        <translation>Käynnistä tähän</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="78"/>
        <source>Set to &apos;0&apos; to boot immediately without displaying the menu, or to &apos;-1&apos; to wait indefinitely</source>
        <translation>Aseta muotoon &apos;0&apos; käynnistääksesi välittömästi ilman valikkonäyttöä, tai  &apos;-1&apos; odottaaksesi loputtomasti </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>Menu timeout</source>
        <translation>Valikon aikavalinta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="104"/>
        <source>Kernel parameters</source>
        <translation>Ytimen parametrit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>seconds</source>
        <translation>sekuntia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>With this option enabled whatever entry you select from the grub boot menu will be saved as the new default for future boots</source>
        <translation>Tämä valinta päällekytkettynä valitsit sitten minkä tahansa grub-valikko-valinnan hyvänsä, se tulee olemaan uusi vakio tulevaisuuden käynnistyksissä </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="127"/>
        <source>Enable saving last boot choice</source>
        <translation>Kytke viimeisimmän käynnistyksen valinnan tallennus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="134"/>
        <source>Manage UEFI Boot Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Background</source>
        <translation>Taustakuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Image</source>
        <translation>Kuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Enable theme</source>
        <translation>Ota teema käyttöön</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Splash</source>
        <translation>Käynnistyskuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>Preview</source>
        <translation>Esikatselu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="319"/>
        <source>Messages</source>
        <translation>Viestit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Very detailed</source>
        <translation>Erittäin tarkka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Detailed (default setting)</source>
        <translation>Tarkka (oletus)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="342"/>
        <source>Limited</source>
        <translation>Rajoitettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>Display log</source>
        <translation>Näytä loki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Display help </source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="453"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>Quit application</source>
        <translation>Lopeta sovellus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="501"/>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>Apply</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="72"/>
        <source>Still running</source>
        <translation>Edelleen käynnissä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>Process still running. Are you sure you want to quit?</source>
        <translation>Prosessi on yhä käynnissä. Haluatko varmasti lopettaa?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Set timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Timeout in seconds:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <location filename="../mainwindow.cpp" line="1073"/>
        <source>Timeout: %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <location filename="../mainwindow.cpp" line="423"/>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>Boot Next: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Removal confirmation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>Are you sure you want to delete this boot entry?
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Select EFI file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>EFI files (*.efi *.EFI)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <location filename="../mainwindow.cpp" line="315"/>
        <location filename="../mainwindow.cpp" line="346"/>
        <location filename="../mainwindow.cpp" line="506"/>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Could not find the source mountpoint for %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Set name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Enter the name for the UEFI menu item:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Something went wrong, could not add entry.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Installing bootsplash, please wait</source>
        <translation>Käynnistysanimaatiota asennetaan, odota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Updating sources</source>
        <translation>Päivitetään lähteitä</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>Installing</source>
        <translation>Asennetaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Could not install the bootsplash.</source>
        <translation>Käynnistyksen splash-kuvaa ei voitu asentaa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Boot Current: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Cannot continue</source>
        <translation>Ei voida jatkaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="462"/>
        <source>Nothing was selected, cannot change boot options. Exiting...</source>
        <translation>Mitään ei valittu, käynnistysvaihtoja ei voitu vaihtaa. Poistutaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>Could not create a temporary folder</source>
        <translation>Ei voitu luoda väliaikaista kansiota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Cannot create chroot environment, cannot change boot options. Exiting...</source>
        <translation>Chroot-ympäristöä ei voitu luoda, käynnistysvaihtoehtoja ei voitu muuttaa. Poistutaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Something went wrong, could not save boot order.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="767"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Updating configuration, please wait</source>
        <translation>Asetuksia päivitetään, odota</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Updating initramfs...</source>
        <translation>Päivitetään initramfs...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <location filename="../mainwindow.cpp" line="1191"/>
        <source>Updating grub...</source>
        <translation>Päivitetään grub...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Changes have been successfully applied.</source>
        <translation>Muutokset on otettu onnistuneesti käyttöön.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="843"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ohjelma yleisille aloitusvalinnoille</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="845"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="847"/>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>MX Boot Options</source>
        <translation>MX Käynnistysasetukset</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="918"/>
        <source>Running in a Virtual Machine</source>
        <translation>Ajettuna virtuaalikoneessa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="919"/>
        <source>You current system is running in a Virtual Machine,
Plymouth bootsplash will work in a limited way, you also won&apos;t be able to preview the theme</source>
        <translation>Tämänhetkinen järjestelmäsi on virtuaalikoneessa ajettuna,
Plymouth-käynnistysanimaatio toimii täten rajatulla tavalla, et myöskään voi esikatsella teemaa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Plymouth packages not installed</source>
        <translation>Plymouth-paketteja ei asennettu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="924"/>
        <source>Plymouth packages are not currently installed.
OK to go ahead and install them?</source>
        <translation>Plymouth-paketteja ei ole tällä hetkellä asennettuna.
Voidaanko jatkaa ja asentaa ne?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Images (*.png *.jpg *.jpeg *.tga)</source>
        <translation>Kuvat (*.png *.jpg *.jpeg *.tga)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Press any key to close</source>
        <translation>Paina mitä tahansa näppäintä sulkeaksesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Log not found</source>
        <translation>Lokitiedostoa ei löytynyt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1049"/>
        <source>Could not find log at </source>
        <translation>Lokitietoja ei löydetty kohteessa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1055"/>
        <source>Edit UEFI Boot Entries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>You can use the Up/Down buttons, or drag &amp; drop items to change boot order.
- Items are listed in the boot order.
- Grayed out lines are inactive.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1108"/>
        <source>Set ac&amp;tive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>&amp;Add entry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1063"/>
        <source>Boot &amp;next</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1064"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1065"/>
        <source>Move &amp;down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1066"/>
        <source>&amp;Remove entry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1067"/>
        <source>Re&amp;set next</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1068"/>
        <source>Change &amp;timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>Move &amp;up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>not set, will boot using list order</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Set &amp;inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1157"/>
        <source>Needs reboot</source>
        <translation>Uudelleenkäynnistys tarvitaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1157"/>
        <source>Plymouth was just installed, you might need to reboot before being able to display previews</source>
        <translation>Plymouth asennettiin juuri, järjestelmä on luultavasti uudelleenkäynnistettävä ennen esikatselukatsantoa </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Click to select theme</source>
        <translation>Klikkaa valitaksesi teema</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Program for selecting common start-up choices</source>
        <translation>Ohjelma yleisille aloitusvalinnoille</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Olet kirjautunut sisään pääkäyttäjänä. Kirjaudu sisään normaalina käyttäjänä käyttääksesi tätä ohjelmaa.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="943"/>
        <source>Select image to display in bootloader</source>
        <translation>Valitse käynnistyslataajassa näytettävä kuva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1222"/>
        <source>Select GRUB theme</source>
        <translation>Valitse GRUB:in teema</translation>
    </message>
</context>
</TS>